@@ -1,26 +1,25 @@
 """This module provides common functionality for all pages on the site."""
 
-import logging
 import os
 import random
+from typing import Dict, Any
 
 from django.conf import settings
+from django.core.handlers.wsgi import WSGIRequest
 from django.db import transaction
 from django.http import HttpResponseBadRequest
 from django.http import HttpResponseRedirect
+from django.http.response import HttpResponse
 from django.shortcuts import render
 from django.urls import reverse
 
 import core.models as models
 from core.lights.lights import Lights
 from core.musiq.musiq import Musiq
-from core.pad import Pad
-from core.settings import Settings
+from core.network_info import NetworkInfo
+from core.settings.settings import Settings
 from core.state_handler import Stateful
 from core.user_manager import UserManager
-from django.core.handlers.wsgi import WSGIRequest
-from django.http.response import HttpResponse
-from typing import Dict, Union, Any
 
 
 class Base(Stateful):
@@ -30,8 +29,12 @@ class Base(Stateful):
         self.settings = Settings(self)
         self.user_manager = UserManager(self)
         self.lights = Lights(self)
-        self.pad = Pad(self)
         self.musiq = Musiq(self)
+        self.network_info = NetworkInfo(self)
+
+    def start(self) -> None:
+        self.lights.start()
+        self.musiq.start()
 
     @classmethod
     def _get_random_hashtag(cls) -> str:
@@ -63,15 +66,15 @@ class Base(Stateful):
         Increments the visitors counter."""
         self._increment_counter()
         return {
-            "voting_system": self.settings.voting_system,
+            "voting_system": self.settings.basic.voting_system,
             "hashtag": self._get_random_hashtag(),
             "controls_enabled": self.user_manager.has_controls(request.user),
-            "pad_enabled": self.user_manager.has_pad(request.user),
             "is_admin": self.user_manager.is_admin(request.user),
             "apk_link": self._get_apk_link(),
-            "youtube_enabled": self.settings.youtube_enabled,
-            "spotify_enabled": self.settings.spotify_enabled,
-            "soundcloud_enabled": self.settings.soundcloud_enabled,
+            "local_enabled": self.settings.platforms.local_enabled,
+            "youtube_enabled": self.settings.platforms.youtube_enabled,
+            "spotify_enabled": self.settings.platforms.spotify_enabled,
+            "soundcloud_enabled": self.settings.platforms.soundcloud_enabled,
         }
 
     def state_dict(self) -> Dict[str, Any]:
@@ -84,9 +87,9 @@ class Base(Stateful):
                 id=1, defaults={"value": 0}
             )[0].value,
             "lights_enabled": self.lights.loop_active.is_set(),
-            "alarm": self.musiq.player.alarm_playing.is_set(),
+            "alarm": self.musiq.playback.alarm_playing.is_set(),
             "default_platform": "spotify"
-            if self.settings.spotify_enabled
+            if self.settings.platforms.spotify_enabled
             else "youtube",
         }
 
@@ -108,10 +111,9 @@ class Base(Stateful):
 
         return HttpResponse()
 
-    @classmethod
-    def logged_in(cls, request: WSGIRequest) -> HttpResponse:
+    def logged_in(self, request: WSGIRequest) -> HttpResponse:
         """This endpoint is visited after every login.
         Redirect the admin to the settings and everybody else to the musiq page."""
-        if request.user.username == "admin":
+        if self.user_manager.is_admin(request.user):
             return HttpResponseRedirect(reverse("settings"))
         return HttpResponseRedirect(reverse("musiq"))
