@@ -3,37 +3,37 @@
 from __future__ import annotations
 
 import logging
+from typing import Any, Dict, Optional, Union, TYPE_CHECKING, List, Tuple, cast, Type
 
 import ipware
+from django.core.handlers.wsgi import WSGIRequest
 from django.forms.models import model_to_dict
-from django.http import HttpResponse
 from django.http import HttpResponseBadRequest
+from django.http.response import HttpResponse, JsonResponse
 from django.shortcuts import render
 from django.views.decorators.csrf import csrf_exempt
 
 import core.musiq.song_utils as song_utils
 from core.models import CurrentSong
 from core.models import QueuedSong
+from core.musiq.controller import Controller
 from core.musiq.localdrive import LocalSongProvider
 from core.musiq.music_provider import (
-    SongProvider,
-    PlaylistProvider,
     MusicProvider,
     WrongUrlError,
     ProviderError,
 )
-from core.musiq.player import Player
-from core.musiq.spotify import SpotifySongProvider, SpotifyPlaylistProvider
+from core.musiq.song_provider import SongProvider
+from core.musiq.playlist_provider import PlaylistProvider
+from core.musiq.playback import Playback
 from core.musiq.soundcloud import SoundcloudSongProvider, SoundcloudPlaylistProvider
+from core.musiq.spotify import SpotifySongProvider, SpotifyPlaylistProvider
 from core.musiq.suggestions import Suggestions
 from core.musiq.youtube import (
     YoutubeSongProvider,
     YoutubePlaylistProvider,
 )
 from core.state_handler import Stateful
-from django.core.handlers.wsgi import WSGIRequest
-from django.http.response import HttpResponse, JsonResponse
-from typing import Any, Dict, Optional, Union, TYPE_CHECKING, List, Tuple
 
 if TYPE_CHECKING:
     from core.base import Base
@@ -49,8 +49,12 @@ class Musiq(Stateful):
 
         self.queue = QueuedSong.objects
 
-        self.player = Player(self)
-        self.player.start()
+        self.playback = Playback(self)
+        self.controller = Controller(self)
+
+    def start(self) -> None:
+        self.controller.start()
+        self.playback.start()
 
     def do_request_music(
         self,
@@ -68,79 +72,64 @@ class Musiq(Stateful):
         providers: List[MusicProvider] = []
 
         provider: MusicProvider
+        music_provider_class: Union[Type[PlaylistProvider], Type[SongProvider]]
+        local_provider_class: Type[MusicProvider]
+        soundcloud_provider_class: Type[MusicProvider]
+        spotify_provider_class: Type[MusicProvider]
+        youtube_provider_class: Type[MusicProvider]
         if playlist:
-            if key is not None:
-                # an archived song was requested.
-                # The key determines the PlaylistProvider
-                provider = PlaylistProvider.create(self, query, key)
-                if provider is None:
-                    return False, "No provider found for requested playlist", None
-                providers.append(provider)
-            else:
-                # try to use spotify if the user did not specifically request youtube
-                if self.base.settings.soundcloud_enabled:
-                    soundcloud_provider = SoundcloudPlaylistProvider(self, query, key)
+            music_provider_class = PlaylistProvider
+            local_provider_class = PlaylistProvider
+            soundcloud_provider_class = SoundcloudPlaylistProvider
+            spotify_provider_class = SpotifyPlaylistProvider
+            youtube_provider_class = YoutubePlaylistProvider
+        else:
+            music_provider_class = SongProvider
+            local_provider_class = LocalSongProvider
+            soundcloud_provider_class = SoundcloudSongProvider
+            spotify_provider_class = SpotifySongProvider
+            youtube_provider_class = YoutubeSongProvider
+
+        if key is not None:
+            # an archived entry was requested.
+            # The key determines the Provider
+            provider = music_provider_class.create(self, query, key)
+            if provider is None:
+                return False, "No provider found for requested key", None
+            providers.append(provider)
+        else:
+            if platform == "local":
+                # local music can only be searched explicitly
+                providers.append(local_provider_class(self, query, key))
+            if self.base.settings.platforms.soundcloud_enabled:
+                try:
+                    soundcloud_provider = soundcloud_provider_class(self, query, key)
                     if platform == "soundcloud":
                         providers.insert(0, soundcloud_provider)
                     else:
                         providers.append(soundcloud_provider)
-                if self.base.settings.spotify_enabled:
-                    spotify_provider = SpotifyPlaylistProvider(self, query, key)
+                except WrongUrlError:
+                    pass
+            if self.base.settings.platforms.spotify_enabled:
+                try:
+                    spotify_provider = spotify_provider_class(self, query, key)
                     if platform == "spotify":
                         providers.insert(0, spotify_provider)
                     else:
                         providers.append(spotify_provider)
-                if self.base.settings.youtube_enabled:
-                    youtube_provider = YoutubePlaylistProvider(self, query, key)
+                except WrongUrlError:
+                    pass
+            if self.base.settings.platforms.youtube_enabled:
+                try:
+                    youtube_provider = youtube_provider_class(self, query, key)
                     if platform == "youtube":
                         providers.insert(0, youtube_provider)
                     else:
                         providers.append(youtube_provider)
-        else:
-            if key is not None:
-                # an archived song was requested.
-                # The key determines the SongProvider
-                provider = SongProvider.create(self, query, key)
-                if provider is None:
-                    return False, "No provider found for requested song", None
-                providers.append(provider)
-            else:
-                if platform == "local":
-                    # if a local provider was requested,
-                    # use only this one as its only possible source is the database
-                    providers.append(LocalSongProvider(self, query, key))
-                else:
-                    if self.base.settings.soundcloud_enabled:
-                        try:
-                            soundcloud_provider = SoundcloudSongProvider(
-                                self, query, key
-                            )
-                            if platform == "soundcloud":
-                                providers.insert(0, soundcloud_provider)
-                            else:
-                                providers.append(soundcloud_provider)
-                        except WrongUrlError:
-                            pass
-                    if self.base.settings.spotify_enabled:
-                        try:
-                            spotify_provider = SpotifySongProvider(self, query, key)
-                            if platform == "spotify":
-                                providers.insert(0, spotify_provider)
-                            else:
-                                providers.append(spotify_provider)
-                        except WrongUrlError:
-                            pass
-                    if self.base.settings.youtube_enabled:
-                        try:
-                            youtube_provider = YoutubeSongProvider(self, query, key)
-                            if platform == "youtube":
-                                providers.insert(0, youtube_provider)
-                            else:
-                                providers.append(youtube_provider)
-                        except WrongUrlError:
-                            pass
+                except WrongUrlError:
+                    pass
 
-        if not len(providers):
+        if not providers:
             return False, "No backend configured to handle your request.", None
 
         fallback = False
@@ -154,13 +143,20 @@ class Musiq(Stateful):
             except ProviderError:
                 # this provider cannot provide this song, use the next provider
                 # if this was the last provider, show its error
-                if i == len(providers) - 1:
+                # in new music only mode, do not allow fallbacks
+                if self.base.settings.basic.new_music_only or i == len(providers) - 1:
                     return False, provider.error, None
                 fallback = True
         message = provider.ok_message
         queue_key = None
         if not playlist:
-            queue_key = provider.queued_song.id
+            queued_song = cast(SongProvider, provider).queued_song
+            if not queued_song:
+                logging.error(
+                    "no placeholder was created for query '%s' and key '%s'", query, key
+                )
+                return False, "No placeholder was created", None
+            queue_key = queued_song.id
         if fallback:
             message += " (used fallback)"
         return True, message, queue_key
@@ -181,7 +177,7 @@ class Musiq(Stateful):
             ikey = int(key)
 
         # only get ip on user requests
-        if self.base.settings.logging_enabled:
+        if self.base.settings.basic.logging_enabled:
             request_ip, _ = ipware.get_client_ip(request)
             if request_ip is None:
                 request_ip = ""
@@ -191,15 +187,14 @@ class Musiq(Stateful):
         successful, message, queue_key = self.do_request_music(
             request_ip, query, ikey, playlist, platform
         )
-        if successful:
-            return JsonResponse({"message": message, "key": queue_key})
-        else:
+        if not successful:
             return HttpResponseBadRequest(message)
+        return JsonResponse({"message": message, "key": queue_key})
 
     def request_radio(self, request: WSGIRequest) -> HttpResponse:
         """Endpoint to request radio for the current song."""
         # only get ip on user requests
-        if self.base.settings.logging_enabled:
+        if self.base.settings.basic.logging_enabled:
             request_ip, _ = ipware.get_client_ip(request)
             if request_ip is None:
                 request_ip = ""
@@ -218,7 +213,7 @@ class Musiq(Stateful):
         """This endpoint is part of the API and exempt from CSRF checks.
         Shareberry uses this endpoint."""
         # only get ip on user requests
-        if self.base.settings.logging_enabled:
+        if self.base.settings.basic.logging_enabled:
             request_ip, _ = ipware.get_client_ip(request)
             if request_ip is None:
                 request_ip = ""
@@ -233,14 +228,15 @@ class Musiq(Stateful):
         successful, message, _ = self.do_request_music(
             request_ip, query, None, False, "spotify"
         )
-        if successful:
-            return HttpResponse(message)
-        else:
+        if not successful:
             return HttpResponseBadRequest(message)
+        return HttpResponse(message)
 
     def index(self, request: WSGIRequest) -> HttpResponse:
         """Renders the /musiq page."""
         context = self.base.context(request)
+        context["additional_keywords"] = self.base.settings.basic.additional_keywords
+        context["forbidden_keywords"] = self.base.settings.basic.forbidden_keywords
         return render(request, "musiq.html", context)
 
     def state_dict(self) -> Dict[str, Any]:
@@ -252,7 +248,7 @@ class Musiq(Stateful):
             current_song = None
         song_queue = []
         all_songs = self.queue.all()
-        if self.base.settings.voting_system:
+        if self.base.settings.basic.voting_system:
             all_songs = all_songs.order_by("-votes", "index")
         for song in all_songs:
             song_dict = model_to_dict(song)
@@ -275,11 +271,11 @@ class Musiq(Stateful):
             }
         else:
             state_dict["current_song"] = current_song
-        state_dict["paused"] = self.player.paused()
-        state_dict["progress"] = self.player.progress()
-        state_dict["shuffle"] = self.player.shuffle
-        state_dict["repeat"] = self.player.repeat
-        state_dict["autoplay"] = self.player.autoplay
-        state_dict["volume"] = self.player.volume
+        state_dict["paused"] = self.playback.paused()
+        state_dict["progress"] = self.playback.progress()
+        state_dict["shuffle"] = self.controller.shuffle
+        state_dict["repeat"] = self.controller.repeat
+        state_dict["autoplay"] = self.controller.autoplay
+        state_dict["volume"] = self.controller.volume
         state_dict["song_queue"] = song_queue
         return state_dict
