@@ -1,17 +1,18 @@
 """This module provides some utility functions concerning songs."""
 
 import os
+import re
+from typing import TYPE_CHECKING
 
 import mutagen.easymp4
 
 from main import settings
-from typing import TYPE_CHECKING
 
 if TYPE_CHECKING:
     from typing_extensions import TypedDict
     from core.musiq.music_provider import ArchivedPlaylist
 
-    Metadata = TypedDict(
+    Metadata = TypedDict(  # pylint: disable=invalid-name
         "Metadata",
         {
             "artist": str,
@@ -33,6 +34,7 @@ def get_path(basename: str) -> str:
 
 
 def determine_url_type(url: str) -> str:
+    """Returns the service the given url corresponds to."""
     if url.startswith("local_library/"):
         return "local"
     if url.startswith("https://www.youtube.com/"):
@@ -101,3 +103,14 @@ def get_metadata(path: str) -> "Metadata":
         metadata["duration"] = -1
 
     return metadata
+
+
+def contains_keywords(title: str, keywords: str) -> bool:
+    words = re.split(r"[,\s]+", keywords.strip())
+    # delete empty matches
+    words = [word for word in words if word]
+
+    for word in words:
+        if re.search(word, title, re.IGNORECASE):
+            return True
+    return False
