@@ -2,21 +2,20 @@
 
 from __future__ import annotations
 
+from typing import Optional, List, Tuple, TYPE_CHECKING
 from urllib.parse import urlparse
 
-from django.http import HttpResponse
-from core.musiq.spotify_web import OAuthClient
+from django.http.response import HttpResponse
 
 from core.models import Setting
 from core.musiq import song_utils
-from core.musiq.music_provider import SongProvider, PlaylistProvider
-from django.http.response import HttpResponse
-from typing import Dict, Optional, Union, List, Tuple, TYPE_CHECKING, Any
+from core.musiq.song_provider import SongProvider
+from core.musiq.playlist_provider import PlaylistProvider
+from core.musiq.spotify_web import OAuthClient
 
 if TYPE_CHECKING:
     from core.musiq.musiq import Musiq
     from core.musiq.song_utils import Metadata
-    from core.musiq.player import Player
 
 
 class Spotify:
@@ -48,7 +47,7 @@ class Spotify:
             "search",
             params={
                 "q": query,
-                "limit": "10",
+                "limit": "20",
                 "market": "from_token",
                 "type": "playlist" if playlist else "track",
             },
@@ -90,7 +89,7 @@ class SpotifySongProvider(SongProvider, Spotify):
 
     @staticmethod
     def get_id_from_internal_url(url: str) -> str:
-        """Constructs and returns the internal id based on the given url."""
+        """Returns the internal id based on the given url."""
         return url.split(":")[-1]
 
     def __init__(
@@ -108,22 +107,28 @@ class SpotifySongProvider(SongProvider, Spotify):
     def check_available(self) -> bool:
         return self.gather_metadata()
 
-    # track_info is of type mopidy.models.Track, but mopidy should not be a dependency, so no import
-    def gather_metadata(self, track_info: Any = None) -> bool:
+    def gather_metadata(self) -> bool:
         """Fetches metadata for this song's uri from Spotify."""
         if not self.id:
             results = self.web_client.get(
                 "search",
                 params={
                     "q": self.query,
-                    "limit": "1",
+                    "limit": "50",
                     "market": "from_token",
                     "type": "track",
                 },
             )
-            try:
-                result = results["tracks"]["items"][0]
-            except IndexError:
+
+            # apply the filterlist from the settings
+            for item in results["tracks"]["items"]:
+                if not song_utils.contains_keywords(
+                    item["name"], self.musiq.base.settings.basic.forbidden_keywords
+                ):
+                    result = item
+                    break
+            else:
+                # all tracks got filtered
                 return False
         else:
             result = self.web_client.get(f"tracks/{self.id}", params={"limit": "1"},)
@@ -171,7 +176,7 @@ class SpotifySongProvider(SongProvider, Spotify):
         result = self.web_client.get(
             "recommendations",
             params={
-                "limit": self.musiq.base.settings.max_playlist_items,
+                "limit": self.musiq.base.settings.basic.max_playlist_items,
                 "market": "from_token",
                 "seed_tracks": self.id,
             },
