@@ -9,18 +9,6 @@ import os
 import pickle
 import subprocess
 from contextlib import contextmanager
-from urllib.parse import parse_qs
-from urllib.parse import urlparse
-
-import requests
-import youtube_dl
-from django.conf import settings
-from django.http import HttpResponse, HttpResponseBadRequest
-
-import core.musiq.song_utils as song_utils
-from core.musiq.music_provider import SongProvider, PlaylistProvider
-from core.util import background_thread
-from django.http.response import HttpResponse
 from typing import (
     Any,
     Dict,
@@ -30,6 +18,17 @@ from typing import (
     Iterator,
     cast,
 )
+from urllib.parse import parse_qs
+from urllib.parse import urlparse
+
+import requests
+import youtube_dl
+from django.conf import settings
+from django.http.response import HttpResponse
+
+import core.musiq.song_utils as song_utils
+from core.musiq.song_provider import SongProvider
+from core.musiq.playlist_provider import PlaylistProvider
 
 if TYPE_CHECKING:
     from core.musiq.musiq import Musiq
@@ -40,11 +39,13 @@ if TYPE_CHECKING:
 def youtube_session() -> Iterator[requests.Session]:
     """This context opens a requests session and loads the youtube cookies file."""
     session = requests.session()
+
+    pickle_file = os.path.join(settings.BASE_DIR, "config/youtube_cookies.pickle")
+
     try:
-        with open(
-            os.path.join(settings.BASE_DIR, "config/youtube_cookies.pickle"), "rb"
-        ) as f:
-            session.cookies.update(pickle.load(f))
+        if os.path.getsize(pickle_file) > 0:
+            with open(pickle_file, "rb") as f:
+                session.cookies.update(pickle.load(f))
     except FileNotFoundError:
         pass
 
@@ -54,9 +55,7 @@ def youtube_session() -> Iterator[requests.Session]:
     session.headers.update(headers)
     yield session
 
-    with open(
-        os.path.join(settings.BASE_DIR, "config/youtube_cookies.pickle"), "wb"
-    ) as f:
+    with open(pickle_file, "wb") as f:
         pickle.dump(session.cookies, f)
 
 
@@ -100,6 +99,7 @@ class Youtube:
             "default_search": "auto",
             "postprocessors": [
                 {"key": "FFmpegMetadata"},
+                # https://github.com/ytdl-org/youtube-dl/pull/25717
                 # {
                 #     "key": "EmbedThumbnail",
                 #     # overwrite any thumbnails already present
@@ -126,7 +126,7 @@ class Youtube:
         with youtube_session() as session:
             params = {
                 "client": "youtube",
-                "q": query,
+                "q": query[:100],  # queries longer than 100 characters are not accepted
                 "xhr": "t",  # this makes the response be a json file
             }
             response = session.get(
@@ -176,7 +176,7 @@ class YoutubeSongProvider(SongProvider, Youtube):
         self.id = self.info_dict["id"]
 
         size = self.info_dict["filesize"]
-        max_size = self.musiq.base.settings.max_download_size * 1024 * 1024
+        max_size = self.musiq.base.settings.basic.max_download_size * 1024 * 1024
         if (
             max_size != 0
             and self.check_cached() is None
@@ -200,7 +200,7 @@ class YoutubeSongProvider(SongProvider, Youtube):
             try:
                 os.remove(thumbnail)
             except FileNotFoundError:
-                logging.info("tried to delete " + thumbnail + " but does not exist")
+                logging.info("tried to delete %s but does not exist", thumbnail)
 
             try:
                 # tag the file with replaygain to perform volume normalization
@@ -219,8 +219,8 @@ class YoutubeSongProvider(SongProvider, Youtube):
             error = e
 
         if error is not None or location is None:
-            logging.error("accessible video could not be downloaded: " + str(self.id))
-            logging.error("location: " + str(location))
+            logging.error("accessible video could not be downloaded: %s", self.id)
+            logging.error("location: %s", location)
             logging.error(error)
             return False
         return True
@@ -362,7 +362,9 @@ class YoutubePlaylistProvider(PlaylistProvider, Youtube):
     def fetch_metadata(self) -> bool:
         # in case of a radio playist, restrict the number of songs that are downloaded
         if self.is_radio():
-            self.ydl_opts["playlistend"] = self.musiq.base.settings.max_playlist_items
+            self.ydl_opts[
+                "playlistend"
+            ] = self.musiq.base.settings.basic.max_playlist_items
 
         try:
             with youtube_dl.YoutubeDL(self.ydl_opts) as ydl:
