@@ -1,3 +1,4 @@
+let state = null;
 let toastTimeout = 2000;
 let currentToastId = 0;
 function infoToast(firstLine, secondLine) {
@@ -170,13 +171,18 @@ function decideScrolling(span, seconds_per_pixel, static_seconds) {
 }
 
 function updatePlatformClasses() {
+	$('#local').removeClass('icon_enabled');
 	$('#youtube').removeClass('icon_enabled');
 	$('#spotify').removeClass('icon_enabled');
 	$('#soundcloud').removeClass('icon_enabled');
+	$('#local').addClass('icon_disabled');
 	$('#youtube').addClass('icon_disabled');
 	$('#spotify').addClass('icon_disabled');
 	$('#soundcloud').addClass('icon_disabled');
-	if (Cookies.get('platform') == 'youtube') {
+	if (Cookies.get('platform') == 'local') {
+		$('#local').removeClass('icon_disabled');
+		$('#local').addClass('icon_enabled');
+	} else if (Cookies.get('platform') == 'youtube') {
 		$('#youtube').removeClass('icon_disabled');
 		$('#youtube').addClass('icon_enabled');
 	} else if (Cookies.get('platform') == 'spotify') {
@@ -389,6 +395,12 @@ $(document).ready(function() {
 		Cookies.set('theme', 'dark', { expires: 7 });
 	});
 
+	$('#local').on('click tap', function() {
+		if ($(this).hasClass('icon_enabled'))
+			return
+		Cookies.set('platform', 'local', { expires: 1 });
+		updatePlatformClasses();
+	});
 	$('#youtube').on('click tap', function() {
 		if ($(this).hasClass('icon_enabled'))
 			return
@@ -410,4 +422,29 @@ $(document).ready(function() {
 
 	// request initial state update
 	getState();
+
+	$('#goto_update').on('click tap', function() {
+		location.href = '/settings/#show_changelog';
+		if (location.pathname.endsWith('/settings/')) {
+			location.reload();
+		}
+	})
+	$('#remind_updates').on('click tap', function() {
+		let tomorrow = new Date(new Date().getTime() + 24 * 60 * 60 * 1000);
+		Cookies.set('ignore_updates', '', {expires: tomorrow});
+		$('#update-banner').slideUp('fast');
+	})
+	$('#ignore_updates').on('click tap', function() {
+		Cookies.set('ignore_updates', '', {expires: 365});
+		$('#update-banner').slideUp('fast');
+	})
+	if (ADMIN) {
+		if (Cookies.get("ignore_updates") === undefined) {
+			$.get(urls['upgrade_available']).done(function(response) {
+				if (response) {
+					$('#update-banner').slideDown('fast');
+				}
+			})
+		}
+	}
 });
