@@ -1,4 +1,3 @@
-let state = null;
 let animationInProgress = false;
 
 specificState = function (newState) {
@@ -172,10 +171,10 @@ function createQueueItem(song) {
 	let index = $('<div/>')
 		.addClass('queue_index')
 		.addClass('queue_handle')
-	if (!VOTING_SYSTEM || CONTROLS_ENABLED) {
-		index.text(song.index)
-	} else {
+	if (VOTING_SYSTEM) {
 		index.text(song.votes)
+	} else {
+		index.text(song.index)
 	}
 	index.appendTo(entry_div);
 	if (song.internal_url) {
@@ -197,18 +196,7 @@ function createQueueItem(song) {
 	let controls = $('<span/>')
 		.addClass('queue_info_controls')
 		.appendTo(info);
-	if (!VOTING_SYSTEM || CONTROLS_ENABLED) {
-		let up = $('<i/>')
-			.addClass('fas')
-			.addClass('fa-level-up-alt')
-			.addClass('prioritize')
-			.appendTo(controls);
-		let down = $('<i/>')
-			.addClass('fas')
-			.addClass('fa-trash-alt')
-			.addClass('remove')
-			.appendTo(controls);
-	} else {
+	if (VOTING_SYSTEM) {
 		let previous_vote = Cookies.get('vote_' + song.id);
 		let up = $('<i/>')
 			.addClass('fas')
@@ -227,6 +215,18 @@ function createQueueItem(song) {
 		}
 		down.appendTo(controls);
 	}
+	if (!VOTING_SYSTEM || CONTROLS_ENABLED) {
+		let up = $('<i/>')
+			.addClass('fas')
+			.addClass('fa-level-up-alt')
+			.addClass('prioritize')
+			.appendTo(controls);
+		let down = $('<i/>')
+			.addClass('fas')
+			.addClass('fa-trash-alt')
+			.addClass('remove')
+			.appendTo(controls);
+	}
 	return li;
 }
 function rebuildSongQueue(newState) {
